==> haskell-hasql-transaction-1.0.1.1-386-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql-transaction.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hasql-transaction
version:              1.0.1.1
visibility:           public
id:                   hasql-transaction-1.0.1.1-H7ehcIQpYgC1xlMpLUdemb
key:                  hasql-transaction-1.0.1.1-H7ehcIQpYgC1xlMpLUdemb
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/hasql-transaction
synopsis:
    Composable abstraction over retryable transactions for Hasql

category:             Hasql, Database, PostgreSQL
abi:                  d14588997ded8bdc14ef25d97372904d
exposed:              True
exposed-modules:      Hasql.Transaction Hasql.Transaction.Sessions
hidden-modules:
    Hasql.Transaction.Private.Prelude Hasql.Transaction.Private.Model
    Hasql.Transaction.Private.SQL Hasql.Transaction.Private.Statements
    Hasql.Transaction.Private.Sessions
    Hasql.Transaction.Private.Transaction

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hasql-transaction-1.0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hasql-transaction-1.0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hasql-transaction-1.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql-transaction
hs-libraries:         HShasql-transaction-1.0.1.1-H7ehcIQpYgC1xlMpLUdemb
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    bytestring-tree-builder-0.2.7.13-CjdQ31ruZO8GL5Vco1Pcp6
    contravariant-1.5.5-p3peIMeiUA4Z37z2EtgYi
    contravariant-extras-0.3.5.4-55ftugxfRMl5DZHT7luCXJ
    hasql-1.5.0.5-HRwvYPLzYhM9K1MKHwukHo mtl-2.2.2 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hasql-transaction/html/hasql-transaction.haddock

haddock-html:         /usr/share/doc/haskell-hasql-transaction/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hasql-transaction-1.0.1.1-408-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql-transaction.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hasql-transaction
version:              1.0.1.1
visibility:           public
id:                   hasql-transaction-1.0.1.1-DxfkXw1WfVa4E97a2soCNT
key:                  hasql-transaction-1.0.1.1-DxfkXw1WfVa4E97a2soCNT
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/hasql-transaction
synopsis:
    Composable abstraction over retryable transactions for Hasql

category:             Hasql, Database, PostgreSQL
abi:                  7ca3615e5e20b3728b85a1e3870fef50
exposed:              True
exposed-modules:      Hasql.Transaction Hasql.Transaction.Sessions
hidden-modules:
    Hasql.Transaction.Private.Prelude Hasql.Transaction.Private.Model
    Hasql.Transaction.Private.SQL Hasql.Transaction.Private.Statements
    Hasql.Transaction.Private.Sessions
    Hasql.Transaction.Private.Transaction

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hasql-transaction-1.0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hasql-transaction-1.0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hasql-transaction-1.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql-transaction
hs-libraries:         HShasql-transaction-1.0.1.1-DxfkXw1WfVa4E97a2soCNT
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    bytestring-tree-builder-0.2.7.13-LW63W1yJv2k9XeG3BA2AGj
    contravariant-1.5.5-p3peIMeiUA4Z37z2EtgYi
    contravariant-extras-0.3.5.4-55ftugxfRMl5DZHT7luCXJ
    hasql-1.5.0.5-GyUCDmolcLALaXTTlK3At6 mtl-2.2.2 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hasql-transaction/html/hasql-transaction.haddock

haddock-html:         /usr/share/doc/haskell-hasql-transaction/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
